@@ -10,8 +10,7 @@
 # 
 # Class::CodeStyler is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+# the Free Software Foundation; version 2 of the License.
 # 
 # Class::CodeStyler is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,8 +29,9 @@ require 5.005_62;
 use strict;
 use warnings;
 use vars qw($VERSION $BUILD);
-$VERSION = 0.07;
-$BUILD = 'Friday April 28 21:56:42 GMT 2006';
+$VERSION = 0.25;
+$BUILD = 'Wednesday February 21 21:21:18 BST 2006';
+use Carp qw(confess);
 # ----------------------------------------------------------------------------------------------------
 {
 	package Class::CodeStyler::Element::Abstract;
@@ -40,117 +40,212 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	use Class::STL::ClassMembers::Constructor;
 	sub prepare
 	{
-		use Carp qw(confess);
 		confess __PACKAGE__ . "::prepare() -- pure virtual function must be overridden.";
 	}
 }
 # ----------------------------------------------------------------------------------------------------
 {
-	package Class::CodeStyler::Program;
+	package Class::CodeStyler::CodeText;
+	use stl;
+	use base qw(Class::STL::Containers::Stack);
+	use Class::STL::ClassMembers
+		Class::STL::ClassMembers::DataMember->new(name => 'newline_is_on',	default => 1),
+		Class::STL::ClassMembers::DataMember->new(name => 'indent_is_on', default => 1),
+		Class::STL::ClassMembers::DataMember->new(name => '_indent_next', default => 1),
+		Class::STL::ClassMembers::DataMember->new(name => 'current_tab', default => 0),
+		Class::STL::ClassMembers::DataMember->new(name => 'tab_type', default => 'spaces', validate => '(hard|spaces)'),
+		Class::STL::ClassMembers::DataMember->new(name => 'tab_size', default => 2),
+		Class::STL::ClassMembers::DataMember->new(name => 'debug', default => 0),
+		Class::STL::ClassMembers::DataMember->new(name => 'raw_is_on', default => 0);
+	use Class::STL::ClassMembers::Constructor;
+	sub append_newline 
+	{
+		my $self = shift;
+		return if ($self->raw_is_on());
+		$self->push($self->factory("\n"));
+		$self->_indent_next(1);
+		print STDERR "NEWLINE:\n" if ($self->debug());
+	}
+	sub append_text
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->push($self->factory($self->current_indent() . $code));
+		print STDERR "CODE   :@{[ $self->current_indent() ]}${code}\n" if ($self->debug());
+		$self->_indent_next(0);
+	}
+	sub current_indent
+	{
+		my $self = shift;
+		return '' if ($self->raw_is_on());
+		return '' if (!$self->indent_is_on());
+		return '' unless ($self->_indent_next());
+		my $tabchar = $self->tab_type() eq 'hard' ? "\t" : ' ';
+		return ($tabchar x ($self->current_tab() * $self->tab_size()));
+	}
+}
+# ----------------------------------------------------------------------------------------------------
+{
+	package Class::CodeStyler::FindName;
+	use stl;
+	use base qw(Class::STL::Utilities::FunctionObject::UnaryFunction);
+	use Class::STL::ClassMembers qw( name );
+	use Class::STL::ClassMembers::Constructor;
+	sub function_operator
+	{
+		my $self = shift;
+		my $arg = shift; # element object
+		return $arg->program_name() eq $self->name() ? $arg : 0;
+	}
+}
+# ----------------------------------------------------------------------------------------------------
+{
+	package Class::CodeStyler::Program::Abstract;
 	use base qw(Class::CodeStyler::Element::Abstract);
-	use stl 0.26;
+	use stl qw( find_if stack list iterator find for_each mem_fun );
 	use UNIVERSAL qw(isa can);
 	use Class::STL::ClassMembers 
 	(
 		qw(
-			program_name sections code_text _bracket_stack 
-			_parent _insert_point _jump_stack _over_stack
+			program_name segments code_text 
+			_bracket_stack _parent _insert_point _jump_stack _over_stack _anchor_stack
 		),
 		Class::STL::ClassMembers::DataMember->new(name => 'suppress_comments', default => 0),
 		Class::STL::ClassMembers::DataMember->new(name => 'tab_size', default => 2),
 		Class::STL::ClassMembers::DataMember->new(name => 'tab_type', default => 'spaces', validate => '(hard|spaces)'),
 		Class::STL::ClassMembers::DataMember->new(name => 'debug', default => 0),
-		Class::STL::ClassMembers::DataMember->new(name => '_current_tab', default => 0),
-		Class::STL::ClassMembers::DataMember->new(name => '_newline_is_on',	default => 1),
-		Class::STL::ClassMembers::DataMember->new(name => '_indent_is_on', default => 1),
-		Class::STL::ClassMembers::DataMember->new(name => '_indent_next', default => 1),
 		Class::STL::ClassMembers::DataMember->new(name => 'divider_length', default => 70),
 		Class::STL::ClassMembers::DataMember->new(name => 'divider_char', default => '-'),
-		Class::STL::ClassMembers::DataMember->new(name => 'comment_start_char', default => ''),
+		Class::STL::ClassMembers::DataMember->new(name => 'comment_start_char', default => '#'),
 		Class::STL::ClassMembers::DataMember->new(name => 'comment_block_begin_char', default => ''),
 		Class::STL::ClassMembers::DataMember->new(name => 'comment_block_end_char', default => ''),
 		Class::STL::ClassMembers::DataMember->new(name => 'comment_block_char', default => ''),
+		Class::STL::ClassMembers::DataMember->new(name => 'disable_newline', default => 0),
+		Class::STL::ClassMembers::DataMember->new(name => 'print_bookmarks', default => 0),
+		Class::STL::ClassMembers::DataMember->new(name => 'open_block_on_newline', default => 1),
 	);
 	use Class::STL::ClassMembers::Constructor;
+	sub exists
+	{
+		my $self = shift;
+		my $name = shift;
+		my $s;
+		return $s->p_element()
+			if ($s = find_if($self->segments()->begin(), $self->segments()->end(), 
+				Class::CodeStyler::FindName->new(name => $name)));
+		return 0;
+	}
 	sub new_extra
 	{
 		my $self = shift;
-		$self->code_text(stack()) unless (defined($self->code_text()));
-		$self->sections(list(element_type => 'Class::CodeStyler::Element::Abstract'));
+		$self->code_text(Class::CodeStyler::CodeText->new(
+				debug => $self->debug(),
+				tab_size => $self->tab_size(),
+				tab_type => $self->tab_type(),
+			))
+			unless (defined($self->code_text()));
+		$self->segments(list(element_type => 'Class::CodeStyler::Element::Abstract'));
 		$self->_bracket_stack(stack());
 		$self->_jump_stack(stack());
-		$self->_insert_point(iterator($self->sections()->begin()));
-#		$self->_bracket_map(::map());
+		$self->_anchor_stack(stack());
+		$self->_over_stack(stack());
+		$self->_insert_point(iterator($self->segments()->begin()));
 		return $self;
 	}
 	sub add
 	{
 		my $self = shift;
-		foreach my $code (grep(ref($_), @_))
+		foreach my $code (@_)
 		{
+			confess "@{[ __PACKAGE__ ]}->add(): Undefined object!" unless (defined($code));
 			if (ref($code) && $code->isa(__PACKAGE__))
 			{
 				$code->code_text($self->code_text());
 				$code->_parent($self);
+				map
+				(
+					$self->add($_), 
+					grep
+					(
+						!$_->isa('Class::CodeStyler::Bookmark') || !find($self->segments()->begin(), $self->segments()->end(), $_->data()),
+						$code->segments()->to_array()
+					)
+				);
+				next;
 			}
-			$self->sections()->insert($self->_insert_point(), $code);
+			elsif (ref($code) && $code->isa('Class::CodeStyler::Element::Abstract'))
+			{
+				$code->owner($self);
+			}
+			elsif (!ref($code))
+			{
+				$self->add(Class::CodeStyler::Code->new(code => $code));
+				next;
+			}
+			else
+			{
+				next;
+			}
+			$self->segments()->insert($self->_insert_point(), 1, $code);
 		}
 	}
 	sub code
 	{
 		my $self = shift;
-		my $code = shift;
-		$self->add(Class::CodeStyler::Code->new(code => $code, owner => $self));
+		my $code = @_ ? shift : '';
+		$self->add(Class::CodeStyler::Code->new(code => $code));
 	}
 	sub open_block
 	{
 		my $self = shift;
 		my $bracket = shift || '{';
 		my %_bracket_pairs = ( '(' => ')', '{' => '}', '[' => ']', '<' => '>' );
-		$self->add(Class::CodeStyler::OpenBlock->new(bracket_char => $bracket, owner => $self));
+		$self->add(Class::CodeStyler::OpenBlock->new(bracket_char => $bracket));
 		$self->_bracket_stack()->push($self->_bracket_stack()->factory($_bracket_pairs{$bracket}));
 		return;
 	}
 	sub close_block
 	{
 		my $self = shift;
+		return unless ($self->_bracket_stack()->size()); #ignore unmatched 'open_block'
 		my $bracket = $self->_bracket_stack()->top()->data();
 		$self->_bracket_stack()->pop();
-		$self->add(Class::CodeStyler::CloseBlock->new(bracket_char => $bracket, owner => $self));
+		$self->add(Class::CodeStyler::CloseBlock->new(bracket_char => $bracket));
 		return;
 	}
 	sub newline_on
 	{
 		my $self = shift;
-		$self->add(Class::CodeStyler::ToggleNewline->new(on => 1, owner => $self));
+		$self->add(Class::CodeStyler::ToggleNewline->new(on => 1));
 	}
 	sub newline_off
 	{
 		my $self = shift;
-		$self->add(Class::CodeStyler::ToggleNewline->new(on => 0, owner => $self));
+		$self->add(Class::CodeStyler::ToggleNewline->new(on => 0));
 	}
 	sub indent_on
 	{
 		my $self = shift;
-		$self->add(Class::CodeStyler::ToggleIndent->new(on => 1, owner => $self));
+		$self->add(Class::CodeStyler::ToggleIndent->new(on => 1));
 	}
 	sub indent_off
 	{
 		my $self = shift;
-		$self->add(Class::CodeStyler::ToggleIndent->new(on => 0, owner => $self));
+		$self->add(Class::CodeStyler::ToggleIndent->new(on => 0));
 	}
 	sub over
 	{
 		my $self = shift;
 		my $indent = shift || 1;
-		$self->add(Class::CodeStyler::Indent->new(indent => $indent, owner => $self));
+		$self->add(Class::CodeStyler::Indent->new(indent => $indent));
 		$self->_over_stack()->push($self->_over_stack()->factory($indent));
 		return;
 	}
 	sub back
 	{
 		my $self = shift;
-		$self->add(Class::CodeStyler::Indent->new(indent => -($self->_over_stack()->top()->data()), owner => $self));
+		return unless ($self->_over_stack()->size()); #ignore unmatched 'back'
+		$self->add(Class::CodeStyler::Indent->new(indent => -($self->_over_stack()->top()->data())));
 		$self->_over_stack()->pop();
 		return;
 	}
@@ -158,36 +253,54 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	{
 		my $self = shift;
 		my $txt = shift;
-		$self->add(Class::CodeStyler::Comment->new(data => $txt, owner => $self));
+		$self->add(Class::CodeStyler::Comment->new(data => $txt));
 	}
 	sub divider
 	{
 		my $self = shift;
-		$self->add(Class::CodeStyler::Divider->new(owner => $self));
+		$self->add(Class::CodeStyler::Divider->new());
+	}
+	sub anchor_set
+	{
+		my $self = shift;
+		$self->add(Class::CodeStyler::Anchor->new(data => "@{[ 
+				$self->_insert_point()->at_end() 
+					? $self->_insert_point()->p_container()->size() 
+					: $self->_insert_point()->arr_idx() 
+			]}"));
+		$self->_anchor_stack()->push($self->_insert_point()->prev()->clone());
+	}
+	sub anchor_return
+	{
+		my $self = shift;
+		return unless($self->_anchor_stack()->size());
+		$self->_insert_point($self->_anchor_stack()->top()->clone());
+		$self->_anchor_stack()->pop();
 	}
 	sub bookmark
 	{
 		my $self = shift;
 		my $id = shift;
-		$self->add(Class::CodeStyler::Bookmark->new(data => $id, owner => $self));
+		$self->add(Class::CodeStyler::Bookmark->new(data => $id));
 	}
 	sub jump
 	{
 		my $self = shift;
 		my $id = shift;
 		my $found;
-		if ($found = find($self->sections()->begin(), $self->sections()->end(), $id))
+		#TODO: potential bug if comment.data same as bookmark.data (id)!
+		if ($found = find($self->segments()->begin(), $self->segments()->end(), $id))
 		{
 			$self->_jump_stack()->push($self->_insert_point()->clone());
 			$self->_insert_point($found);
-			return;
+			return $found;
 		}
-		use Carp qw(confess);
-		confess "Unknown bookmark '$id'!\n";
+		return 0;
 	}
 	sub return
 	{
 		my $self = shift;
+		return unless($self->_jump_stack()->size());
 		$self->_insert_point($self->_jump_stack()->top()->clone());
 		$self->_jump_stack()->pop();
 	}
@@ -195,25 +308,36 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	{
 		my $self = shift;
 		$self->code_text()->clear();
+		return $self;
 	}
 	sub prepare
 	{
 		my $self = shift;
-		# This works because all 'sections' elements are (ultimately) derived 
+		# This works because all 'segments' elements are (ultimately) derived 
 		# from Class::CodeStyler::Element::Abstract. Recursion via this prepare() will
 		# occure if the element is a Class::CodeStyler::Program.
-		for_each($self->sections()->begin(), $self->sections()->end(), mem_fun('prepare'));
+		for_each($self->segments()->begin(), $self->segments()->end(), mem_fun('prepare'));
+		return $self;
 	}
 	sub print
 	{
 		my $self = shift;
 		return $self->code_text()->join('');
 	}
+	sub raw
+	{
+		my $self = shift;
+		$self->code_text()->raw_is_on(1);
+		$self->code_text()->clear();
+		$self->prepare();
+		my $txt = $self->print();
+		$self->code_text()->raw_is_on('0');
+		return $txt;
+	}
 	sub save
 	{
 		my $self = shift;
 		my $filename = shift || $self->program_name();
-		use Carp qw(confess);
 		confess "save() -- Unable to save -- 'program_name' is not defined."
 			unless defined($filename);
 		open(SAVE, ">@{[ $filename ]}");
@@ -223,10 +347,12 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	{
 		my $self = shift;
 		my $line_number = 1;
+		my @p;
 		foreach (split(/\n/, $self->print()))
 		{
-			print sprintf("%5d %s\n", $line_number++, $_);
+			push(@p, sprintf(" %5d %s", $line_number++, $_));
 		}
+		return join("\n", @p);
 	}
 	sub syntax_check
 	{
@@ -255,65 +381,41 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 		$self->save("@{[ $self->program_name() ]}.EXEC");
 		exec("perl @{[ $self->program_name() ]}.EXEC");
 	}
+	sub run
+	{
+		my $self = shift;
+		$self->save("@{[ $self->program_name() ]}.EXEC");
+		system("perl @{[ $self->program_name() ]}.EXEC");
+	}
 	sub eval
 	{
 		my $self = shift;
-		eval($self->print());
-		use Carp qw(confess);
+		my $code = $self->print();
+		eval($code);
 		confess "**Error in eval:\n$@" if ($@);
 	}
-	# ----------------------------------------------------------------------------------------------------
-	#	PRIVATE FUNCTIONS
-	# ----------------------------------------------------------------------------------------------------
-	sub _append_newline
-	{
-		my $self = shift;
-		$self->code_text()->push($self->code_text()->factory("\n"));
-		$self->_indent_next(1);
-		print STDERR "NEWLINE:\n" if ($self->debug());
-	}
-	sub _append_text
-	{
-		my $self = shift;
-		my $code = shift;
-		$self->code_text()->push($self->code_text()->factory($self->_current_indent() . $code));
-		print STDERR "CODE   :@{[ $self->_current_indent() ]}${code}\n" if ($self->debug());
-		$self->_indent_next(0);
-	}
-	sub _current_indent
-	{
-		my $self = shift;
-		return '' if (!$self->_indent_is_on());
-		return '' unless (
-			$self->_indent_next() 
-			|| (defined($self->_parent()) && $self->_parent()->_indent_next())
-		);
-		my $tabchar = $self->tab_type() eq 'hard' ? "\t" : ' ';
-		return ($tabchar x ($self->_current_tab() * $self->tab_size()))
-			. (defined($self->_parent()) ? $self->_parent()->_current_indent() : '');
-	}
 }
 # ----------------------------------------------------------------------------------------------------
 {
 	package Class::CodeStyler::Program::Perl; 
-	use base qw(Class::CodeStyler::Program);
+	use base qw(Class::CodeStyler::Program::Abstract);
+	use Class::STL::ClassMembers;
 	use Class::STL::ClassMembers::Constructor;
 	sub new_extra
 	{
 		my $self = shift;
-		$self->SUPER::new_extra(@_);
 		$self->comment_start_char('#');
 	}
 }
 # ----------------------------------------------------------------------------------------------------
 {
 	package Class::CodeStyler::Program::C; 
-	use base qw(Class::CodeStyler::Program);
+	use base qw(Class::CodeStyler::Program::Abstract);
+	use Class::STL::ClassMembers;
 	use Class::STL::ClassMembers::Constructor;
 	sub new_extra
 	{
 		my $self = shift;
-		$self->SUPER::new_extra(@_);
 		$self->comment_start_char('//');
 		$self->comment_block_begin_char('/*');
 		$self->comment_block_char      (' *');
@@ -322,14 +424,133 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 }
 # ----------------------------------------------------------------------------------------------------
 {
-	package Class::CodeStyler::Bookmark;
-	use base qw(Class::CodeStyler::Element::Abstract);
+	package Class::CodeStyler::Program::Pod; 
+	use base qw(Class::CodeStyler::Program::Abstract);
+	use Class::STL::ClassMembers qw( title version type user_email author pdf );
+	use Class::STL::ClassMembers::Constructor;
+	sub new_extra
+	{
+		my $self = shift;
+		$self->comment_start_char('=cut ');
+		$self->code("=pod");
+		$self->code();
+	}
+	sub head1
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code('=head1 ' . $code);
+		$self->code();
+	}
+	sub head2
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code('=head2 ' . $code);
+		$self->code();
+	}
+	sub head3
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code('=head3 ' . $code);
+		$self->code();
+	}
+	sub head4
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code('=head4 ' . $code);
+		$self->code();
+	}
+	sub begin
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code('=begin ' . $code);
+		$self->code();
+	}
+	sub end
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code('=end ' . $code);
+		$self->code();
+	}
+	sub item
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code();
+		$self->code('=item ' . $code);
+		$self->code();
+	}
+	sub literal
+	{
+		my $self = shift;
+		my $code = shift || '';
+		$self->code(' ' . $code);
+		$self->code();
+	}
+	sub page
+	{
+		my $self = shift;
+		$self->code('=page');
+		$self->code();
+	}
+	sub over
+	{
+		my $self = shift;
+		my $indent = shift;
+		$self->code("=over @{[ defined($indent) ? $indent : '' ]}");
+		$self->code();
+	}
+	sub back
+	{
+		my $self = shift;
+		$self->code('=back ');
+		$self->code();
+	}
+	sub to_pdf
+	{
+#>		$self->pdf(Class::CodeStyler::Pod2Pdf->new(
+#>			title => $self->title(),
+#>			version => $self->version(), 
+#>			type => $self->type(), 
+#>			email => $self->user_email(), 
+#>			author => $self->author(), 
+#>		));
+#>		$self->pdf()->produce();
+	}
+}
+# ----------------------------------------------------------------------------------------------------
+{
+package Class::CodeStyler::Anchor;
+use base qw(Class::CodeStyler::Element::Abstract);
+	use Class::STL::ClassMembers;
 	use Class::STL::ClassMembers::Constructor;
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_append_text("# BOOKMARK ---- @{[ $self->data() ]}");
-		$self->owner()->_append_newline();
+		return unless ($self->owner()->print_bookmarks());
+		return if ($self->owner()->code_text()->raw_is_on());
+		$self->owner()->code_text()->append_text("# ANCHOR ---- @{[ $self->data() ]}");
+		$self->owner()->code_text()->append_newline();
+	}
+}
+# ----------------------------------------------------------------------------------------------------
+{
+	package Class::CodeStyler::Bookmark;
+	use base qw(Class::CodeStyler::Element::Abstract);
+	use Class::STL::ClassMembers;
+	use Class::STL::ClassMembers::Constructor;
+	sub prepare
+	{
+		my $self = shift;
+		return unless ($self->owner()->print_bookmarks());
+		return if ($self->owner()->code_text()->raw_is_on());
+		$self->owner()->code_text()->append_text("# BOOKMARK ---- @{[ $self->data() ]}");
+		$self->owner()->code_text()->append_newline();
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -341,10 +562,10 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_append_text($self->bracket_char());
-		return unless ($self->owner()->_newline_is_on());
-		$self->owner()->_current_tab($self->owner()->_current_tab()+1);
-		$self->owner()->_append_newline();
+		$self->owner()->code_text()->append_text($self->bracket_char());
+		return unless ($self->owner()->code_text()->newline_is_on());
+		$self->owner()->code_text()->current_tab($self->owner()->code_text()->current_tab()+1);
+		$self->owner()->code_text()->append_newline();
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -356,9 +577,9 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_current_tab($self->owner()->_current_tab()-1) if ($self->owner()->_newline_is_on());
-		$self->owner()->_append_text($self->bracket_char());
-		$self->owner()->_append_newline() if ($self->owner()->_newline_is_on());
+		$self->owner()->code_text()->current_tab($self->owner()->code_text()->current_tab()-1) if ($self->owner()->code_text()->newline_is_on());
+		$self->owner()->code_text()->append_text($self->bracket_char());
+		$self->owner()->code_text()->append_newline() if ($self->owner()->code_text()->newline_is_on());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -370,20 +591,23 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_append_text($self->code());
-		$self->owner()->_append_newline() if ($self->owner()->_newline_is_on());
+		confess "Undefined 'owner' (@{[ $self->code() ]})!" unless (defined($self->owner()));
+		$self->owner()->code_text()->append_text($self->code());
+		$self->owner()->code_text()->append_newline() if ($self->owner()->code_text()->newline_is_on());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
 {
 	package Class::CodeStyler::Comment;
 	use base qw(Class::CodeStyler::Element::Abstract);
+	use Class::STL::ClassMembers;
 	use Class::STL::ClassMembers::Constructor;
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_append_text($self->owner()->comment_start_char() . $self->data());
-		$self->owner()->_append_newline() if ($self->owner()->_newline_is_on());
+#>		return if ($self->owner()->code_text()->raw_is_on());
+		$self->owner()->code_text()->append_text($self->owner()->comment_start_char() . $self->data());
+		$self->owner()->code_text()->append_newline() if ($self->owner()->code_text()->newline_is_on());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -398,12 +622,14 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 {
 	package Class::CodeStyler::Divider;
 	use base qw(Class::CodeStyler::Element::Abstract);
+	use Class::STL::ClassMembers;
+	use Class::STL::ClassMembers::Constructor;
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_append_text($self->owner()->comment_start_char());
-		$self->owner()->_append_text($self->owner()->divider_char() x $self->owner()->divider_length());
-		$self->owner()->_append_newline() if ($self->owner()->_newline_is_on());
+		$self->owner()->code_text()->append_text($self->owner()->comment_start_char());
+		$self->owner()->code_text()->append_text($self->owner()->divider_char() x $self->owner()->divider_length());
+		$self->owner()->code_text()->append_newline() if ($self->owner()->code_text()->newline_is_on());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -415,7 +641,7 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_newline_is_on($self->on());
+		$self->owner()->code_text()->newline_is_on($self->on());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -427,7 +653,7 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_indent_is_on($self->on());
+		$self->owner()->code_text()->indent_is_on($self->on());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
@@ -439,7 +665,7 @@ $BUILD = 'Friday April 28 21:56:42 GMT 2006';
 	sub prepare
 	{
 		my $self = shift;
-		$self->owner()->_current_tab($self->owner()->_current_tab()+$self->indent());
+		$self->owner()->code_text()->current_tab($self->owner()->code_text()->current_tab()+$self->indent());
 	}
 }
 # ----------------------------------------------------------------------------------------------------
